# README

## Group Number: 17
## Group Members: Nick Stern, Vincent Viego, Summer Yuan, Zach Wehrwein

<!-- Badges -->

[![Build Status](https://travis-ci.org/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject)

[![CoverageStatus](https://coveralls.io/repos/github/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject/badge.svg?branch=master)](https://coveralls.io/github/VV-NS-CY-ZW-CS-207-Organization/cs207-FinalProject?branch=master)
